Struct ExtForeignToplevelHandleV1
pub struct ExtForeignToplevelHandleV1 { /* private fields */ }wayland and Linux only.Expand description
a mapped toplevel
A ext_foreign_toplevel_handle_v1 object represents a mapped toplevel window. A single app may have multiple mapped toplevels.
See also the Request enum for this interface.
Implementations
impl ExtForeignToplevelHandleV1
impl ExtForeignToplevelHandleV1
pub fn closed(&self)
pub fn closed(&self)
the toplevel has been closed
The server will emit no further events on the ext_foreign_toplevel_handle_v1 after this event. Any requests received aside from the destroy request must be ignored. Upon receiving this event, the client should destroy the handle.
Other protocols which extend the ext_foreign_toplevel_handle_v1 interface must also ignore requests other than destructors.
pub fn done(&self)
pub fn done(&self)
all information about the toplevel has been sent
This event is sent after all changes in the toplevel state have been sent.
This allows changes to the ext_foreign_toplevel_handle_v1 properties to be atomically applied. Other protocols which extend the ext_foreign_toplevel_handle_v1 interface may use this event to also atomically apply any pending state.
This event must not be sent after the ext_foreign_toplevel_handle_v1.closed event.
pub fn title(&self, title: String)
pub fn title(&self, title: String)
title change
The title of the toplevel has changed.
The configured state must not be applied immediately. See ext_foreign_toplevel_handle_v1.done for details.
pub fn app_id(&self, app_id: String)
pub fn app_id(&self, app_id: String)
app_id change
The app id of the toplevel has changed.
The configured state must not be applied immediately. See ext_foreign_toplevel_handle_v1.done for details.
pub fn identifier(&self, identifier: String)
pub fn identifier(&self, identifier: String)
a stable identifier for a toplevel
This identifier is used to check if two or more toplevel handles belong to the same toplevel.
The identifier is useful for command line tools or privileged clients which may need to reference an exact toplevel across processes or instances of the ext_foreign_toplevel_list_v1 global.
The compositor must only send this event when the handle is created.
The identifier must be unique per toplevel and it’s handles. Two different toplevels must not have the same identifier. The identifier is only valid as long as the toplevel is mapped. If the toplevel is unmapped the identifier must not be reused. An identifier must not be reused by the compositor to ensure there are no races when sharing identifiers between processes.
An identifier is a string that contains up to 32 printable ASCII bytes. An identifier must not be an empty string. It is recommended that a compositor includes an opaque generation value in identifiers. How the generation value is used when generating the identifier is implementation dependent.